@@ -1,9 +1,9 @@
 
 __pkgname__ = 'phylab'
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 __author__ = 'Bernardo Tomelleri'
 __license__ = 'GPLv3'
 __summary__ = 'A Python module for basic data analysis and curve fitting for Physics laboratory students.'
 __url__ = 'https://github.com/BernardoTomelleri/phylab'
 
-from . import lab
\ No newline at end of file
+from .lab import *
\ No newline at end of file
